# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: orderer/configuration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1borderer/configuration.proto\x12\x07orderer\"\x8e\x01\n\rConsensusType\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x10\n\x08metadata\x18\x02 \x01(\x0c\x12+\n\x05state\x18\x03 \x01(\x0e\x32\x1c.orderer.ConsensusType.State\"0\n\x05State\x12\x10\n\x0cSTATE_NORMAL\x10\x00\x12\x15\n\x11STATE_MAINTENANCE\x10\x01\"_\n\tBatchSize\x12\x19\n\x11max_message_count\x18\x01 \x01(\r\x12\x1a\n\x12\x61\x62solute_max_bytes\x18\x02 \x01(\r\x12\x1b\n\x13preferred_max_bytes\x18\x03 \x01(\r\"\x1f\n\x0c\x42\x61tchTimeout\x12\x0f\n\x07timeout\x18\x01 \x01(\t\"\x1f\n\x0cKafkaBrokers\x12\x0f\n\x07\x62rokers\x18\x01 \x03(\t\"(\n\x13\x43hannelRestrictions\x12\x11\n\tmax_count\x18\x01 \x01(\x04\x42X\n%org.hyperledger.fabric.protos.ordererZ/github.com/hyperledger/fabric-protos-go/ordererb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'orderer.configuration_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%org.hyperledger.fabric.protos.ordererZ/github.com/hyperledger/fabric-protos-go/orderer'
  _CONSENSUSTYPE._serialized_start=41
  _CONSENSUSTYPE._serialized_end=183
  _CONSENSUSTYPE_STATE._serialized_start=135
  _CONSENSUSTYPE_STATE._serialized_end=183
  _BATCHSIZE._serialized_start=185
  _BATCHSIZE._serialized_end=280
  _BATCHTIMEOUT._serialized_start=282
  _BATCHTIMEOUT._serialized_end=313
  _KAFKABROKERS._serialized_start=315
  _KAFKABROKERS._serialized_end=346
  _CHANNELRESTRICTIONS._serialized_start=348
  _CHANNELRESTRICTIONS._serialized_end=388
# @@protoc_insertion_point(module_scope)
