# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: msp/msp_principal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17msp/msp_principal.proto\x12\x06\x63ommon\"\xc6\x01\n\x0cMSPPrincipal\x12\x45\n\x18principal_classification\x18\x01 \x01(\x0e\x32#.common.MSPPrincipal.Classification\x12\x11\n\tprincipal\x18\x02 \x01(\x0c\"\\\n\x0e\x43lassification\x12\x08\n\x04ROLE\x10\x00\x12\x15\n\x11ORGANIZATION_UNIT\x10\x01\x12\x0c\n\x08IDENTITY\x10\x02\x12\r\n\tANONYMITY\x10\x03\x12\x0c\n\x08\x43OMBINED\x10\x04\"q\n\x10OrganizationUnit\x12\x16\n\x0emsp_identifier\x18\x01 \x01(\t\x12&\n\x1eorganizational_unit_identifier\x18\x02 \x01(\t\x12\x1d\n\x15\x63\x65rtifiers_identifier\x18\x03 \x01(\x0c\"\x95\x01\n\x07MSPRole\x12\x16\n\x0emsp_identifier\x18\x01 \x01(\t\x12)\n\x04role\x18\x02 \x01(\x0e\x32\x1b.common.MSPRole.MSPRoleType\"G\n\x0bMSPRoleType\x12\n\n\x06MEMBER\x10\x00\x12\t\n\x05\x41\x44MIN\x10\x01\x12\n\n\x06\x43LIENT\x10\x02\x12\x08\n\x04PEER\x10\x03\x12\x0b\n\x07ORDERER\x10\x04\"\x9d\x01\n\x14MSPIdentityAnonymity\x12M\n\x0e\x61nonymity_type\x18\x01 \x01(\x0e\x32\x35.common.MSPIdentityAnonymity.MSPIdentityAnonymityType\"6\n\x18MSPIdentityAnonymityType\x12\x0b\n\x07NOMINAL\x10\x00\x12\r\n\tANONYMOUS\x10\x01\"=\n\x11\x43ombinedPrincipal\x12(\n\nprincipals\x18\x01 \x03(\x0b\x32\x14.common.MSPPrincipalBS\n$org.hyperledger.fabric.protos.commonZ+github.com/hyperledger/fabric-protos-go/mspb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'msp.msp_principal_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$org.hyperledger.fabric.protos.commonZ+github.com/hyperledger/fabric-protos-go/msp'
  _MSPPRINCIPAL._serialized_start=36
  _MSPPRINCIPAL._serialized_end=234
  _MSPPRINCIPAL_CLASSIFICATION._serialized_start=142
  _MSPPRINCIPAL_CLASSIFICATION._serialized_end=234
  _ORGANIZATIONUNIT._serialized_start=236
  _ORGANIZATIONUNIT._serialized_end=349
  _MSPROLE._serialized_start=352
  _MSPROLE._serialized_end=501
  _MSPROLE_MSPROLETYPE._serialized_start=430
  _MSPROLE_MSPROLETYPE._serialized_end=501
  _MSPIDENTITYANONYMITY._serialized_start=504
  _MSPIDENTITYANONYMITY._serialized_end=661
  _MSPIDENTITYANONYMITY_MSPIDENTITYANONYMITYTYPE._serialized_start=607
  _MSPIDENTITYANONYMITY_MSPIDENTITYANONYMITYTYPE._serialized_end=661
  _COMBINEDPRINCIPAL._serialized_start=663
  _COMBINEDPRINCIPAL._serialized_end=724
# @@protoc_insertion_point(module_scope)
