# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10peer/query.proto\x12\x06protos\"C\n\x16\x43haincodeQueryResponse\x12)\n\nchaincodes\x18\x01 \x03(\x0b\x32\x15.protos.ChaincodeInfo\"s\n\rChaincodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\r\n\x05input\x18\x04 \x01(\t\x12\x0c\n\x04\x65scc\x18\x05 \x01(\t\x12\x0c\n\x04vscc\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\x0c\"=\n\x14\x43hannelQueryResponse\x12%\n\x08\x63hannels\x18\x01 \x03(\x0b\x32\x13.protos.ChannelInfo\"!\n\x0b\x43hannelInfo\x12\x12\n\nchannel_id\x18\x01 \x01(\t\"O\n\x14JoinBySnapshotStatus\x12\x13\n\x0bin_progress\x18\x01 \x01(\x08\x12\"\n\x1a\x62ootstrapping_snapshot_dir\x18\x02 \x01(\tBR\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peer'
  _CHAINCODEQUERYRESPONSE._serialized_start=28
  _CHAINCODEQUERYRESPONSE._serialized_end=95
  _CHAINCODEINFO._serialized_start=97
  _CHAINCODEINFO._serialized_end=212
  _CHANNELQUERYRESPONSE._serialized_start=214
  _CHANNELQUERYRESPONSE._serialized_end=275
  _CHANNELINFO._serialized_start=277
  _CHANNELINFO._serialized_end=310
  _JOINBYSNAPSHOTSTATUS._serialized_start=312
  _JOINBYSNAPSHOTSTATUS._serialized_end=391
# @@protoc_insertion_point(module_scope)
