# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/snapshot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from fabric_protos_python.common import common_pb2 as common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13peer/snapshot.proto\x12\x06protos\x1a\x1bgoogle/protobuf/empty.proto\x1a\x13\x63ommon/common.proto\"n\n\x0fSnapshotRequest\x12\x31\n\x10signature_header\x18\x01 \x01(\x0b\x32\x17.common.SignatureHeader\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\x14\n\x0c\x62lock_number\x18\x03 \x01(\x04\"V\n\rSnapshotQuery\x12\x31\n\x10signature_header\x18\x01 \x01(\x0b\x32\x17.common.SignatureHeader\x12\x12\n\nchannel_id\x18\x02 \x01(\t\";\n\x15SignedSnapshotRequest\x12\x0f\n\x07request\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"6\n\x1dQueryPendingSnapshotsResponse\x12\x15\n\rblock_numbers\x18\x01 \x03(\x04\x32\xeb\x01\n\x08Snapshot\x12\x43\n\x08Generate\x12\x1d.protos.SignedSnapshotRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x41\n\x06\x43\x61ncel\x12\x1d.protos.SignedSnapshotRequest\x1a\x16.google.protobuf.Empty\"\x00\x12W\n\rQueryPendings\x12\x1d.protos.SignedSnapshotRequest\x1a%.protos.QueryPendingSnapshotsResponse\"\x00\x42R\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.snapshot_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peer'
  _SNAPSHOTREQUEST._serialized_start=81
  _SNAPSHOTREQUEST._serialized_end=191
  _SNAPSHOTQUERY._serialized_start=193
  _SNAPSHOTQUERY._serialized_end=279
  _SIGNEDSNAPSHOTREQUEST._serialized_start=281
  _SIGNEDSNAPSHOTREQUEST._serialized_end=340
  _QUERYPENDINGSNAPSHOTSRESPONSE._serialized_start=342
  _QUERYPENDINGSNAPSHOTSRESPONSE._serialized_end=396
  _SNAPSHOT._serialized_start=399
  _SNAPSHOT._serialized_end=634
# @@protoc_insertion_point(module_scope)
