# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/lifecycle/chaincode_definition.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)peer/lifecycle/chaincode_definition.proto\x12\tlifecycle\"^\n\x18\x43haincodeEndorsementInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x15\n\rinit_required\x18\x02 \x01(\x08\x12\x1a\n\x12\x65ndorsement_plugin\x18\x03 \x01(\t\"R\n\x17\x43haincodeValidationInfo\x12\x19\n\x11validation_plugin\x18\x01 \x01(\t\x12\x1c\n\x14validation_parameter\x18\x02 \x01(\x0c\x42\x66\n,org.hyperledger.fabric.protos.peer.lifecycleZ6github.com/hyperledger/fabric-protos-go/peer/lifecycleb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.lifecycle.chaincode_definition_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n,org.hyperledger.fabric.protos.peer.lifecycleZ6github.com/hyperledger/fabric-protos-go/peer/lifecycle'
  _CHAINCODEENDORSEMENTINFO._serialized_start=56
  _CHAINCODEENDORSEMENTINFO._serialized_end=150
  _CHAINCODEVALIDATIONINFO._serialized_start=152
  _CHAINCODEVALIDATIONINFO._serialized_end=234
# @@protoc_insertion_point(module_scope)
