# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ledger/queryresult/kv_query_result.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ledger/queryresult/kv_query_result.proto\x12\x0bqueryresult\x1a\x1fgoogle/protobuf/timestamp.proto\"3\n\x02KV\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x0c\"q\n\x0fKeyModification\x12\r\n\x05tx_id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tis_delete\x18\x04 \x01(\x08\x42n\n0org.hyperledger.fabric.protos.ledger.queryresultZ:github.com/hyperledger/fabric-protos-go/ledger/queryresultb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ledger.queryresult.kv_query_result_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n0org.hyperledger.fabric.protos.ledger.queryresultZ:github.com/hyperledger/fabric-protos-go/ledger/queryresult'
  _KV._serialized_start=90
  _KV._serialized_end=141
  _KEYMODIFICATION._serialized_start=143
  _KEYMODIFICATION._serialized_end=256
# @@protoc_insertion_point(module_scope)
