# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/chaincode.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.common import policies_pb2 as common_dot_policies__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14peer/chaincode.proto\x12\x06protos\x1a\x15\x63ommon/policies.proto\":\n\x0b\x43haincodeID\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\xa1\x01\n\x0e\x43haincodeInput\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\x0c\x12<\n\x0b\x64\x65\x63orations\x18\x02 \x03(\x0b\x32\'.protos.ChaincodeInput.DecorationsEntry\x12\x0f\n\x07is_init\x18\x03 \x01(\x08\x1a\x32\n\x10\x44\x65\x63orationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xdc\x01\n\rChaincodeSpec\x12(\n\x04type\x18\x01 \x01(\x0e\x32\x1a.protos.ChaincodeSpec.Type\x12)\n\x0c\x63haincode_id\x18\x02 \x01(\x0b\x32\x13.protos.ChaincodeID\x12%\n\x05input\x18\x03 \x01(\x0b\x32\x16.protos.ChaincodeInput\x12\x0f\n\x07timeout\x18\x04 \x01(\x05\">\n\x04Type\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06GOLANG\x10\x01\x12\x08\n\x04NODE\x10\x02\x12\x07\n\x03\x43\x41R\x10\x03\x12\x08\n\x04JAVA\x10\x04\"\x84\x01\n\x17\x43haincodeDeploymentSpec\x12-\n\x0e\x63haincode_spec\x18\x01 \x01(\x0b\x32\x15.protos.ChaincodeSpec\x12\x14\n\x0c\x63ode_package\x18\x03 \x01(\x0cJ\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05R\x0e\x65\x66\x66\x65\x63tive_dateR\x08\x65xec_env\"a\n\x17\x43haincodeInvocationSpec\x12-\n\x0e\x63haincode_spec\x18\x01 \x01(\x0b\x32\x15.protos.ChaincodeSpecJ\x04\x08\x02\x10\x03R\x11id_generation_alg\"(\n\x0eLifecycleEvent\x12\x16\n\x0e\x63haincode_name\x18\x01 \x01(\t\"-\n\x07\x43\x44SData\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x14\n\x0cmetadatahash\x18\x02 \x01(\x0c\"\xd4\x01\n\rChaincodeData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04\x65scc\x18\x03 \x01(\t\x12\x0c\n\x04vscc\x18\x04 \x01(\t\x12/\n\x06policy\x18\x05 \x01(\x0b\x32\x1f.common.SignaturePolicyEnvelope\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12\n\n\x02id\x18\x07 \x01(\x0c\x12=\n\x14instantiation_policy\x18\x08 \x01(\x0b\x32\x1f.common.SignaturePolicyEnvelopeBR\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.chaincode_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peer'
  _CHAINCODEINPUT_DECORATIONSENTRY._options = None
  _CHAINCODEINPUT_DECORATIONSENTRY._serialized_options = b'8\001'
  _CHAINCODEID._serialized_start=55
  _CHAINCODEID._serialized_end=113
  _CHAINCODEINPUT._serialized_start=116
  _CHAINCODEINPUT._serialized_end=277
  _CHAINCODEINPUT_DECORATIONSENTRY._serialized_start=227
  _CHAINCODEINPUT_DECORATIONSENTRY._serialized_end=277
  _CHAINCODESPEC._serialized_start=280
  _CHAINCODESPEC._serialized_end=500
  _CHAINCODESPEC_TYPE._serialized_start=438
  _CHAINCODESPEC_TYPE._serialized_end=500
  _CHAINCODEDEPLOYMENTSPEC._serialized_start=503
  _CHAINCODEDEPLOYMENTSPEC._serialized_end=635
  _CHAINCODEINVOCATIONSPEC._serialized_start=637
  _CHAINCODEINVOCATIONSPEC._serialized_end=734
  _LIFECYCLEEVENT._serialized_start=736
  _LIFECYCLEEVENT._serialized_end=776
  _CDSDATA._serialized_start=778
  _CDSDATA._serialized_end=823
  _CHAINCODEDATA._serialized_start=826
  _CHAINCODEDATA._serialized_end=1038
# @@protoc_insertion_point(module_scope)
