# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/proposal_response.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fabric_protos_python.common import policies_pb2 as common_dot_policies__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cpeer/proposal_response.proto\x12\x06protos\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x15\x63ommon/policies.proto\"\xde\x01\n\x10ProposalResponse\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\"\n\x08response\x18\x04 \x01(\x0b\x32\x10.protos.Response\x12\x0f\n\x07payload\x18\x05 \x01(\x0c\x12(\n\x0b\x65ndorsement\x18\x06 \x01(\x0b\x32\x13.protos.Endorsement\x12+\n\x08interest\x18\x07 \x01(\x0b\x32\x19.protos.ChaincodeInterest\"<\n\x08Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\"C\n\x17ProposalResponsePayload\x12\x15\n\rproposal_hash\x18\x01 \x01(\x0c\x12\x11\n\textension\x18\x02 \x01(\x0c\"2\n\x0b\x45ndorsement\x12\x10\n\x08\x65ndorser\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\">\n\x11\x43haincodeInterest\x12)\n\nchaincodes\x18\x01 \x03(\x0b\x32\x15.protos.ChaincodeCall\"\xc6\x01\n\rChaincodeCall\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10\x63ollection_names\x18\x02 \x03(\t\x12\x18\n\x10no_private_reads\x18\x03 \x01(\x08\x12\x18\n\x10no_public_writes\x18\x04 \x01(\x08\x12\x35\n\x0ckey_policies\x18\x05 \x03(\x0b\x32\x1f.common.SignaturePolicyEnvelope\x12\"\n\x1a\x64isregard_namespace_policy\x18\x06 \x01(\x08\x42k\n\"org.hyperledger.fabric.protos.peerB\x17ProposalResponsePackageZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.proposal_response_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerB\027ProposalResponsePackageZ,github.com/hyperledger/fabric-protos-go/peer'
  _PROPOSALRESPONSE._serialized_start=97
  _PROPOSALRESPONSE._serialized_end=319
  _RESPONSE._serialized_start=321
  _RESPONSE._serialized_end=381
  _PROPOSALRESPONSEPAYLOAD._serialized_start=383
  _PROPOSALRESPONSEPAYLOAD._serialized_end=450
  _ENDORSEMENT._serialized_start=452
  _ENDORSEMENT._serialized_end=502
  _CHAINCODEINTEREST._serialized_start=504
  _CHAINCODEINTEREST._serialized_end=566
  _CHAINCODECALL._serialized_start=569
  _CHAINCODECALL._serialized_end=767
# @@protoc_insertion_point(module_scope)
