# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/lifecycle/db.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17peer/lifecycle/db.proto\x12\tlifecycle\"1\n\rStateMetadata\x12\x10\n\x08\x64\x61tatype\x18\x01 \x01(\t\x12\x0e\n\x06\x66ields\x18\x02 \x03(\t\"G\n\tStateData\x12\x0f\n\x05Int64\x18\x01 \x01(\x03H\x00\x12\x0f\n\x05\x42ytes\x18\x02 \x01(\x0cH\x00\x12\x10\n\x06String\x18\x03 \x01(\tH\x00\x42\x06\n\x04TypeBf\n,org.hyperledger.fabric.protos.peer.lifecycleZ6github.com/hyperledger/fabric-protos-go/peer/lifecycleb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.lifecycle.db_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n,org.hyperledger.fabric.protos.peer.lifecycleZ6github.com/hyperledger/fabric-protos-go/peer/lifecycle'
  _STATEMETADATA._serialized_start=38
  _STATEMETADATA._serialized_end=87
  _STATEDATA._serialized_start=89
  _STATEDATA._serialized_end=160
# @@protoc_insertion_point(module_scope)
