# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: msp/identities.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14msp/identities.proto\x12\x03msp\"5\n\x12SerializedIdentity\x12\r\n\x05mspid\x18\x01 \x01(\t\x12\x10\n\x08id_bytes\x18\x02 \x01(\x0c\"a\n\x18SerializedIdemixIdentity\x12\r\n\x05nym_x\x18\x01 \x01(\x0c\x12\r\n\x05nym_y\x18\x02 \x01(\x0c\x12\n\n\x02ou\x18\x03 \x01(\x0c\x12\x0c\n\x04role\x18\x04 \x01(\x0c\x12\r\n\x05proof\x18\x05 \x01(\x0c\x42P\n!org.hyperledger.fabric.protos.mspZ+github.com/hyperledger/fabric-protos-go/mspb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'msp.identities_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!org.hyperledger.fabric.protos.mspZ+github.com/hyperledger/fabric-protos-go/msp'
  _SERIALIZEDIDENTITY._serialized_start=29
  _SERIALIZEDIDENTITY._serialized_end=82
  _SERIALIZEDIDEMIXIDENTITY._serialized_start=84
  _SERIALIZEDIDEMIXIDENTITY._serialized_end=181
# @@protoc_insertion_point(module_scope)
