# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peer/policy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.common import policies_pb2 as common_dot_policies__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11peer/policy.proto\x12\x06protos\x1a\x15\x63ommon/policies.proto\"\x83\x01\n\x11\x41pplicationPolicy\x12;\n\x10signature_policy\x18\x01 \x01(\x0b\x32\x1f.common.SignaturePolicyEnvelopeH\x00\x12)\n\x1f\x63hannel_config_policy_reference\x18\x02 \x01(\tH\x00\x42\x06\n\x04TypeBR\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'peer.policy_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"org.hyperledger.fabric.protos.peerZ,github.com/hyperledger/fabric-protos-go/peer'
  _APPLICATIONPOLICY._serialized_start=53
  _APPLICATIONPOLICY._serialized_end=184
# @@protoc_insertion_point(module_scope)
