# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63ommon/common.proto\x12\x06\x63ommon\x1a\x1fgoogle/protobuf/timestamp.proto\"\x1b\n\nLastConfig\x12\r\n\x05index\x18\x01 \x01(\x04\"H\n\x08Metadata\x12\r\n\x05value\x18\x01 \x01(\x0c\x12-\n\nsignatures\x18\x02 \x03(\x0b\x32\x19.common.MetadataSignature\"@\n\x11MetadataSignature\x12\x18\n\x10signature_header\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\":\n\x06Header\x12\x16\n\x0e\x63hannel_header\x18\x01 \x01(\x0c\x12\x18\n\x10signature_header\x18\x02 \x01(\x0c\"\xb9\x01\n\rChannelHeader\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nchannel_id\x18\x04 \x01(\t\x12\r\n\x05tx_id\x18\x05 \x01(\t\x12\r\n\x05\x65poch\x18\x06 \x01(\x04\x12\x11\n\textension\x18\x07 \x01(\x0c\x12\x15\n\rtls_cert_hash\x18\x08 \x01(\x0c\"1\n\x0fSignatureHeader\x12\x0f\n\x07\x63reator\x18\x01 \x01(\x0c\x12\r\n\x05nonce\x18\x02 \x01(\x0c\"7\n\x07Payload\x12\x1e\n\x06header\x18\x01 \x01(\x0b\x32\x0e.common.Header\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\".\n\x08\x45nvelope\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"v\n\x05\x42lock\x12#\n\x06header\x18\x01 \x01(\x0b\x32\x13.common.BlockHeader\x12\x1f\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x11.common.BlockData\x12\'\n\x08metadata\x18\x03 \x01(\x0b\x32\x15.common.BlockMetadata\"G\n\x0b\x42lockHeader\x12\x0e\n\x06number\x18\x01 \x01(\x04\x12\x15\n\rprevious_hash\x18\x02 \x01(\x0c\x12\x11\n\tdata_hash\x18\x03 \x01(\x0c\"\x19\n\tBlockData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x0c\"!\n\rBlockMetadata\x12\x10\n\x08metadata\x18\x01 \x03(\x0c\"[\n\x14OrdererBlockMetadata\x12\'\n\x0blast_config\x18\x01 \x01(\x0b\x32\x12.common.LastConfig\x12\x1a\n\x12\x63onsenter_metadata\x18\x02 \x01(\x0c*\xc0\x01\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x07SUCCESS\x10\xc8\x01\x12\x10\n\x0b\x42\x41\x44_REQUEST\x10\x90\x03\x12\x0e\n\tFORBIDDEN\x10\x93\x03\x12\x0e\n\tNOT_FOUND\x10\x94\x03\x12\x1d\n\x18REQUEST_ENTITY_TOO_LARGE\x10\x9d\x03\x12\x1a\n\x15INTERNAL_SERVER_ERROR\x10\xf4\x03\x12\x14\n\x0fNOT_IMPLEMENTED\x10\xf5\x03\x12\x18\n\x13SERVICE_UNAVAILABLE\x10\xf7\x03*\xea\x01\n\nHeaderType\x12\x0b\n\x07MESSAGE\x10\x00\x12\n\n\x06\x43ONFIG\x10\x01\x12\x11\n\rCONFIG_UPDATE\x10\x02\x12\x18\n\x14\x45NDORSER_TRANSACTION\x10\x03\x12\x17\n\x13ORDERER_TRANSACTION\x10\x04\x12\x15\n\x11\x44\x45LIVER_SEEK_INFO\x10\x05\x12\x15\n\x11\x43HAINCODE_PACKAGE\x10\x06\"\x04\x08\x07\x10\x07\"\x04\x08\x08\x10\x08\"\x04\x08\t\x10\t*\x14PEER_RESOURCE_UPDATE*\x14PEER_ADMIN_OPERATION*\x11TOKEN_TRANSACTION*t\n\x12\x42lockMetadataIndex\x12\x0e\n\nSIGNATURES\x10\x00\x12\x13\n\x0bLAST_CONFIG\x10\x01\x1a\x02\x08\x01\x12\x17\n\x13TRANSACTIONS_FILTER\x10\x02\x12\x0f\n\x07ORDERER\x10\x03\x1a\x02\x08\x01\x12\x0f\n\x0b\x43OMMIT_HASH\x10\x04\x42V\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/commonb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/common'
  _BLOCKMETADATAINDEX.values_by_name["LAST_CONFIG"]._options = None
  _BLOCKMETADATAINDEX.values_by_name["LAST_CONFIG"]._serialized_options = b'\010\001'
  _BLOCKMETADATAINDEX.values_by_name["ORDERER"]._options = None
  _BLOCKMETADATAINDEX.values_by_name["ORDERER"]._serialized_options = b'\010\001'
  _STATUS._serialized_start=986
  _STATUS._serialized_end=1178
  _HEADERTYPE._serialized_start=1181
  _HEADERTYPE._serialized_end=1415
  _BLOCKMETADATAINDEX._serialized_start=1417
  _BLOCKMETADATAINDEX._serialized_end=1533
  _LASTCONFIG._serialized_start=64
  _LASTCONFIG._serialized_end=91
  _METADATA._serialized_start=93
  _METADATA._serialized_end=165
  _METADATASIGNATURE._serialized_start=167
  _METADATASIGNATURE._serialized_end=231
  _HEADER._serialized_start=233
  _HEADER._serialized_end=291
  _CHANNELHEADER._serialized_start=294
  _CHANNELHEADER._serialized_end=479
  _SIGNATUREHEADER._serialized_start=481
  _SIGNATUREHEADER._serialized_end=530
  _PAYLOAD._serialized_start=532
  _PAYLOAD._serialized_end=587
  _ENVELOPE._serialized_start=589
  _ENVELOPE._serialized_end=635
  _BLOCK._serialized_start=637
  _BLOCK._serialized_end=755
  _BLOCKHEADER._serialized_start=757
  _BLOCKHEADER._serialized_end=828
  _BLOCKDATA._serialized_start=830
  _BLOCKDATA._serialized_end=855
  _BLOCKMETADATA._serialized_start=857
  _BLOCKMETADATA._serialized_end=890
  _ORDERERBLOCKMETADATA._serialized_start=892
  _ORDERERBLOCKMETADATA._serialized_end=983
# @@protoc_insertion_point(module_scope)
