# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/configuration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63ommon/configuration.proto\x12\x06\x63ommon\" \n\x10HashingAlgorithm\x12\x0c\n\x04name\x18\x01 \x01(\t\"*\n\x19\x42lockDataHashingStructure\x12\r\n\x05width\x18\x01 \x01(\r\"%\n\x10OrdererAddresses\x12\x11\n\taddresses\x18\x01 \x03(\t\"\x1a\n\nConsortium\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x95\x01\n\x0c\x43\x61pabilities\x12<\n\x0c\x63\x61pabilities\x18\x01 \x03(\x0b\x32&.common.Capabilities.CapabilitiesEntry\x1aG\n\x11\x43\x61pabilitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.common.Capability:\x02\x38\x01\"\x0c\n\nCapabilityBV\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/commonb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.configuration_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/common'
  _CAPABILITIES_CAPABILITIESENTRY._options = None
  _CAPABILITIES_CAPABILITIESENTRY._serialized_options = b'8\001'
  _HASHINGALGORITHM._serialized_start=38
  _HASHINGALGORITHM._serialized_end=70
  _BLOCKDATAHASHINGSTRUCTURE._serialized_start=72
  _BLOCKDATAHASHINGSTRUCTURE._serialized_end=114
  _ORDERERADDRESSES._serialized_start=116
  _ORDERERADDRESSES._serialized_end=153
  _CONSORTIUM._serialized_start=155
  _CONSORTIUM._serialized_end=181
  _CAPABILITIES._serialized_start=184
  _CAPABILITIES._serialized_end=333
  _CAPABILITIES_CAPABILITIESENTRY._serialized_start=262
  _CAPABILITIES_CAPABILITIESENTRY._serialized_end=333
  _CAPABILITY._serialized_start=335
  _CAPABILITY._serialized_end=347
# @@protoc_insertion_point(module_scope)
