# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/configtx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.common import common_pb2 as common_dot_common__pb2
from fabric_protos_python.common import policies_pb2 as common_dot_policies__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63ommon/configtx.proto\x12\x06\x63ommon\x1a\x13\x63ommon/common.proto\x1a\x15\x63ommon/policies.proto\"W\n\x0e\x43onfigEnvelope\x12\x1e\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x0e.common.Config\x12%\n\x0blast_update\x18\x02 \x01(\x0b\x32\x10.common.Envelope\"R\n\x06\x43onfig\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12*\n\rchannel_group\x18\x02 \x01(\x0b\x32\x13.common.ConfigGroupJ\x04\x08\x03\x10\x04R\x04type\"Z\n\x14\x43onfigUpdateEnvelope\x12\x15\n\rconfig_update\x18\x01 \x01(\x0c\x12+\n\nsignatures\x18\x02 \x03(\x0b\x32\x17.common.ConfigSignature\"\xf1\x01\n\x0c\x43onfigUpdate\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12%\n\x08read_set\x18\x02 \x01(\x0b\x32\x13.common.ConfigGroup\x12&\n\twrite_set\x18\x03 \x01(\x0b\x32\x13.common.ConfigGroup\x12=\n\risolated_data\x18\x05 \x03(\x0b\x32&.common.ConfigUpdate.IsolatedDataEntry\x1a\x33\n\x11IsolatedDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01J\x04\x08\x04\x10\x05R\x04type\"\x98\x03\n\x0b\x43onfigGroup\x12\x0f\n\x07version\x18\x01 \x01(\x04\x12/\n\x06groups\x18\x02 \x03(\x0b\x32\x1f.common.ConfigGroup.GroupsEntry\x12/\n\x06values\x18\x03 \x03(\x0b\x32\x1f.common.ConfigGroup.ValuesEntry\x12\x33\n\x08policies\x18\x04 \x03(\x0b\x32!.common.ConfigGroup.PoliciesEntry\x12\x12\n\nmod_policy\x18\x05 \x01(\t\x1a\x42\n\x0bGroupsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.common.ConfigGroup:\x02\x38\x01\x1a\x42\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.common.ConfigValue:\x02\x38\x01\x1a\x45\n\rPoliciesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.common.ConfigPolicy:\x02\x38\x01\"A\n\x0b\x43onfigValue\x12\x0f\n\x07version\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x12\n\nmod_policy\x18\x03 \x01(\t\"S\n\x0c\x43onfigPolicy\x12\x0f\n\x07version\x18\x01 \x01(\x04\x12\x1e\n\x06policy\x18\x02 \x01(\x0b\x32\x0e.common.Policy\x12\x12\n\nmod_policy\x18\x03 \x01(\t\">\n\x0f\x43onfigSignature\x12\x18\n\x10signature_header\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x42V\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/commonb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.configtx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$org.hyperledger.fabric.protos.commonZ.github.com/hyperledger/fabric-protos-go/common'
  _CONFIGUPDATE_ISOLATEDDATAENTRY._options = None
  _CONFIGUPDATE_ISOLATEDDATAENTRY._serialized_options = b'8\001'
  _CONFIGGROUP_GROUPSENTRY._options = None
  _CONFIGGROUP_GROUPSENTRY._serialized_options = b'8\001'
  _CONFIGGROUP_VALUESENTRY._options = None
  _CONFIGGROUP_VALUESENTRY._serialized_options = b'8\001'
  _CONFIGGROUP_POLICIESENTRY._options = None
  _CONFIGGROUP_POLICIESENTRY._serialized_options = b'8\001'
  _CONFIGENVELOPE._serialized_start=77
  _CONFIGENVELOPE._serialized_end=164
  _CONFIG._serialized_start=166
  _CONFIG._serialized_end=248
  _CONFIGUPDATEENVELOPE._serialized_start=250
  _CONFIGUPDATEENVELOPE._serialized_end=340
  _CONFIGUPDATE._serialized_start=343
  _CONFIGUPDATE._serialized_end=584
  _CONFIGUPDATE_ISOLATEDDATAENTRY._serialized_start=521
  _CONFIGUPDATE_ISOLATEDDATAENTRY._serialized_end=572
  _CONFIGGROUP._serialized_start=587
  _CONFIGGROUP._serialized_end=995
  _CONFIGGROUP_GROUPSENTRY._serialized_start=790
  _CONFIGGROUP_GROUPSENTRY._serialized_end=856
  _CONFIGGROUP_VALUESENTRY._serialized_start=858
  _CONFIGGROUP_VALUESENTRY._serialized_end=924
  _CONFIGGROUP_POLICIESENTRY._serialized_start=926
  _CONFIGGROUP_POLICIESENTRY._serialized_end=995
  _CONFIGVALUE._serialized_start=997
  _CONFIGVALUE._serialized_end=1062
  _CONFIGPOLICY._serialized_start=1064
  _CONFIGPOLICY._serialized_end=1147
  _CONFIGSIGNATURE._serialized_start=1149
  _CONFIGSIGNATURE._serialized_end=1211
# @@protoc_insertion_point(module_scope)
