# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ledger/rwset/rwset.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18ledger/rwset/rwset.proto\x12\x05rwset\"\x83\x01\n\x0eTxReadWriteSet\x12\x33\n\ndata_model\x18\x01 \x01(\x0e\x32\x1f.rwset.TxReadWriteSet.DataModel\x12\'\n\x08ns_rwset\x18\x02 \x03(\x0b\x32\x15.rwset.NsReadWriteSet\"\x13\n\tDataModel\x12\x06\n\x02KV\x10\x00\"x\n\x0eNsReadWriteSet\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05rwset\x18\x02 \x01(\x0c\x12\x44\n\x17\x63ollection_hashed_rwset\x18\x03 \x03(\x0b\x32#.rwset.CollectionHashedReadWriteSet\"e\n\x1c\x43ollectionHashedReadWriteSet\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x14\n\x0chashed_rwset\x18\x02 \x01(\x0c\x12\x16\n\x0epvt_rwset_hash\x18\x03 \x01(\x0c\"x\n\x11TxPvtReadWriteSet\x12\x33\n\ndata_model\x18\x01 \x01(\x0e\x32\x1f.rwset.TxReadWriteSet.DataModel\x12.\n\x0cns_pvt_rwset\x18\x02 \x03(\x0b\x32\x18.rwset.NsPvtReadWriteSet\"f\n\x11NsPvtReadWriteSet\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12>\n\x14\x63ollection_pvt_rwset\x18\x02 \x03(\x0b\x32 .rwset.CollectionPvtReadWriteSet\"C\n\x19\x43ollectionPvtReadWriteSet\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\r\n\x05rwset\x18\x02 \x01(\x0c\x42\x62\n*org.hyperledger.fabric.protos.ledger.rwsetZ4github.com/hyperledger/fabric-protos-go/ledger/rwsetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ledger.rwset.rwset_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*org.hyperledger.fabric.protos.ledger.rwsetZ4github.com/hyperledger/fabric-protos-go/ledger/rwset'
  _TXREADWRITESET._serialized_start=36
  _TXREADWRITESET._serialized_end=167
  _TXREADWRITESET_DATAMODEL._serialized_start=148
  _TXREADWRITESET_DATAMODEL._serialized_end=167
  _NSREADWRITESET._serialized_start=169
  _NSREADWRITESET._serialized_end=289
  _COLLECTIONHASHEDREADWRITESET._serialized_start=291
  _COLLECTIONHASHEDREADWRITESET._serialized_end=392
  _TXPVTREADWRITESET._serialized_start=394
  _TXPVTREADWRITESET._serialized_end=514
  _NSPVTREADWRITESET._serialized_start=516
  _NSPVTREADWRITESET._serialized_end=618
  _COLLECTIONPVTREADWRITESET._serialized_start=620
  _COLLECTIONPVTREADWRITESET._serialized_end=687
# @@protoc_insertion_point(module_scope)
