# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: transientstore/transientstore.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fabric_protos_python.ledger.rwset import rwset_pb2 as ledger_dot_rwset_dot_rwset__pb2
from fabric_protos_python.peer import collection_pb2 as peer_dot_collection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#transientstore/transientstore.proto\x12\x0etransientstore\x1a\x18ledger/rwset/rwset.proto\x1a\x15peer/collection.proto\"\xa2\x02\n\x1fTxPvtReadWriteSetWithConfigInfo\x12\x13\n\x0b\x65ndorsed_at\x18\x01 \x01(\x04\x12+\n\tpvt_rwset\x18\x02 \x01(\x0b\x32\x18.rwset.TxPvtReadWriteSet\x12\x62\n\x12\x63ollection_configs\x18\x03 \x03(\x0b\x32\x46.transientstore.TxPvtReadWriteSetWithConfigInfo.CollectionConfigsEntry\x1aY\n\x16\x43ollectionConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.protos.CollectionConfigPackage:\x02\x38\x01\x42\x66\n,org.hyperledger.fabric.protos.transientstoreZ6github.com/hyperledger/fabric-protos-go/transientstoreb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'transientstore.transientstore_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n,org.hyperledger.fabric.protos.transientstoreZ6github.com/hyperledger/fabric-protos-go/transientstore'
  _TXPVTREADWRITESETWITHCONFIGINFO_COLLECTIONCONFIGSENTRY._options = None
  _TXPVTREADWRITESETWITHCONFIGINFO_COLLECTIONCONFIGSENTRY._serialized_options = b'8\001'
  _TXPVTREADWRITESETWITHCONFIGINFO._serialized_start=105
  _TXPVTREADWRITESETWITHCONFIGINFO._serialized_end=395
  _TXPVTREADWRITESETWITHCONFIGINFO_COLLECTIONCONFIGSENTRY._serialized_start=306
  _TXPVTREADWRITESETWITHCONFIGINFO_COLLECTIONCONFIGSENTRY._serialized_end=395
# @@protoc_insertion_point(module_scope)
