# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: orderer/etcdraft/metadata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1forderer/etcdraft/metadata.proto\x12\x08\x65tcdraft\"U\n\rBlockMetadata\x12\x15\n\rconsenter_ids\x18\x01 \x03(\x04\x12\x19\n\x11next_consenter_id\x18\x02 \x01(\x04\x12\x12\n\nraft_index\x18\x03 \x01(\x04\"\'\n\x0f\x43lusterMetadata\x12\x14\n\x0c\x61\x63tive_nodes\x18\x01 \x03(\x04\x42j\n.org.hyperledger.fabric.protos.orderer.etcdraftZ8github.com/hyperledger/fabric-protos-go/orderer/etcdraftb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'orderer.etcdraft.metadata_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.org.hyperledger.fabric.protos.orderer.etcdraftZ8github.com/hyperledger/fabric-protos-go/orderer/etcdraft'
  _BLOCKMETADATA._serialized_start=45
  _BLOCKMETADATA._serialized_end=130
  _CLUSTERMETADATA._serialized_start=132
  _CLUSTERMETADATA._serialized_end=171
# @@protoc_insertion_point(module_scope)
